/**
 *  设备授权管理 - 油机SDK授权页面
 *  数据对象的Dto
 * */

import {columnsProps, pageInput} from "/@/api/admin/shareDto/shareDto";

/**
 * @name: 数据对象接口
 * @description: 设备授权管理 - 油机SDK授权页面文件筛选条件
 * @author wyoujia
 * @date 2023-55-29 11:55:55
*/

/**
 * 条件查询模块
 */
export interface oilSdkFilterModel {
  /**油站名称 */
  OilStation?: string | null,
  /**项目名称 */
  Project?: string | null,
  /**设备SN */
  SN?: string | null,
  /**授权码*/
  Key?: string,
  Time?:string,
  /**开始的时间 */
  BeginTime?: string | null,
  /**开始的时间 */
  EndTime?: string  | null,
}

/**
 * 表格信息
 */
export interface oilSdkTableModel {
  /**id*/
  guid: number,
  /**日期*/
  date?: string,
  /**加油站*/
  oilStation: string | null,
  /**项目名称*/
  projectName?: string | null,
  /**项目名称*/
  project?: string | null,
  /**设备SN号*/
  sn: string | null,
  /**密钥key*/
  key: string | null,
  /**过期时间*/
  expiedTime: string | null,
  /**状态*/
  state: string | null | number,
  /**备注*/
  remark: string | null
}

/**
 * @name: 数据对象接口
 * @description: 设备授权管理 - 油机SDK授权页面
 * @author wyoujia
 * @date 2023-12-29 11:12:08
*/
export interface OilSdkAuthorDto {
  time: string,
  /**加载显示 */
  loading: boolean,
  /**条件查询模块 */
  Filter: oilSdkFilterModel,
  /**表格信息 */
  tableModel: oilSdkTableModel [] | [],
  /**动态表头 */
  dynamicColumns: columnsProps [] | [],
  /**分页标识 */
  pageInput: pageInput,
  /**分页总数 */
  total: number,
}

/**结果输出*/
export interface oilSdkAuthorDtoResult {
  /** 是否成功标记 */
  success?: boolean
  /** 编码 */
  code?: string | null
  /** 消息 */
  msg?: string | null
  /** 分页信息输出 */
  data?: oilSdkAuthorPageOutput
}

/** 分页信息输出*/
export interface oilSdkAuthorPageOutput{
  /**
   * 数据总数
   * @format int64
   */
  total?: number
  /** 数据 */
  list?: oilSdkTableModel[] | null
}

/** 分页信息输入 */
export interface oilSdkAuthorPostPageDto {
  /**
   * 当前页标
   * @format int32
   */
  CurrentPage?: number
  /**
   * 每页大小
   * @format int32
   */
  PageSize?: number
  Filter?: oilSdkFilterModel
}
/** 审核数据输入 */
export interface FueilingSdkAuthInput{
  /**id*/
  guid: number,
  /**加油站*/
  oilStation: string | null,
  /**项目名称*/
  project?: string | null,
  /**设备SN号*/
  sn: string | null,
  /**授权码*/
  key: string | null,
  /**状态*/
  state: string | null | number,
  /**授权开始时间*/
  expiedTime: string | null,
  /**备注*/
  remark: string | null
}
/**结果输出*/
export interface ResultOutputBoolean {
  /** 是否成功标记 */
  success?: boolean
  /** 编码 */
  code?: string | null
  /** 消息 */
  msg?: string | null
  /** 分页信息输出 */
  data?: boolean
}
